==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/collection/request/DeviceEnrollmentConfigurationCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.List;
import java.util.Map;

import odata.msgraph.client.beta.complex.HasPayloadLinkResultItem;
import odata.msgraph.client.beta.entity.DeviceEnrollmentConfiguration;
import odata.msgraph.client.beta.entity.request.DeviceEnrollmentConfigurationRequest;
import odata.msgraph.client.beta.entity.request.EnrollmentConfigurationAssignmentRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

public class DeviceEnrollmentConfigurationCollectionRequest extends CollectionPageEntityRequest<DeviceEnrollmentConfiguration, DeviceEnrollmentConfigurationRequest>{

    protected ContextPath contextPath;

    public DeviceEnrollmentConfigurationCollectionRequest(ContextPath contextPath) {
        super(contextPath, DeviceEnrollmentConfiguration.class, cp -> new DeviceEnrollmentConfigurationRequest(cp), SchemaInfo.INSTANCE);
        this.contextPath = contextPath;
    }

    public EnrollmentConfigurationAssignmentCollectionRequest assignments() {
        return new EnrollmentConfigurationAssignmentCollectionRequest(contextPath.addSegment("assignments"));
    }

    public EnrollmentConfigurationAssignmentRequest assignments(String id) {
        return new EnrollmentConfigurationAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id.toString())));
    }

    @Action(name = "hasPayloadLinks")
    @JsonIgnore
    public CollectionPageNonEntityRequest<HasPayloadLinkResultItem> hasPayloadLinks(List<String> payloadIds) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("payloadIds", "Collection(Edm.String)", Checks.checkIsAscii(payloadIds))
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.hasPayloadLinks"), HasPayloadLinkResultItem.class, _parameters, odata.msgraph.client.beta.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/collection/request/DeviceEnrollmentConfigurationCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.CollectionPageNonEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.complex.HasPayloadLinkResultItem;
import odata.msgraph.client.beta.entity.DeviceEnrollmentConfiguration;
import odata.msgraph.client.beta.entity.request.DeviceEnrollmentConfigurationRequest;
import odata.msgraph.client.beta.entity.request.EnrollmentConfigurationAssignmentRequest;

public class DeviceEnrollmentConfigurationCollectionRequest extends CollectionPageEntityRequest<DeviceEnrollmentConfiguration, DeviceEnrollmentConfigurationRequest>{

    protected ContextPath contextPath;

    public DeviceEnrollmentConfigurationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, DeviceEnrollmentConfiguration.class, cp -> new DeviceEnrollmentConfigurationRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public EnrollmentConfigurationAssignmentRequest assignments(String id) {
        return new EnrollmentConfigurationAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public EnrollmentConfigurationAssignmentCollectionRequest assignments() {
        return new EnrollmentConfigurationAssignmentCollectionRequest(contextPath.addSegment("assignments"), Optional.empty());
    }

    @Action(name = "hasPayloadLinks")
    @JsonIgnore
    public CollectionPageNonEntityRequest<HasPayloadLinkResultItem> hasPayloadLinks(List<String> payloadIds) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("payloadIds", "Collection(Edm.String)", Checks.checkIsAscii(payloadIds))
            .build();
        return CollectionPageNonEntityRequest.forAction(this.contextPath.addActionOrFunctionSegment("microsoft.graph.hasPayloadLinks"), HasPayloadLinkResultItem.class, _parameters);
    }

}
